@@ -39,12 +39,7 @@
  *                                                                           *
  * ========================================================================= */
 
-/*===========================================================================*\
- *                                                                           *             
- *   $Revision$                                                         *
- *   $Date$                   *
- *                                                                           *
-\*===========================================================================*/
+
 
 // -------------------------------------------------------------- includes ----
 
@@ -276,7 +271,7 @@ int main(int argc, char **argv)
     {
       case 'v': verbose = true; break;
       case 'o': ofname = optarg;  break;
-      case 'h': usage_and_exit(0);
+      case 'h': usage_and_exit(0); break;
       default:  usage_and_exit(1);
     }
   }
